@@ -27,7 +27,6 @@
 #include <KApplicationTrader>
 #include <KIO/MimeTypeFinderJob>
 #include <KLocalizedString>
-#include <KProcess>
 #include <KSycoca>
 #include <KWaylandExtras>
 #include <KWindowSystem>
@@ -141,17 +140,11 @@ void AppChooserDialog::onApplicationSelected(const QString &desktopFile, const b
     }
 
     if (KWindowSystem::isPlatformWayland()) {
-        KWaylandExtras::requestXdgActivationToken(m_theDialog, KWaylandExtras::lastInputSerial(m_theDialog), m_selectedApplication);
-
-        connect(
-            KWaylandExtras::self(),
-            &KWaylandExtras::xdgActivationTokenArrived,
-            this,
-            [this](int /*serial*/, const QString &token) {
-                m_activationToken = token;
-                accept();
-            },
-            Qt::SingleShotConnection);
+        auto tokenFuture = KWaylandExtras::xdgActivationToken(m_theDialog, m_selectedApplication);
+        tokenFuture.then(this, [this](const QString &token) {
+            m_activationToken = token;
+            accept();
+        });
     } else {
         accept();
     }
@@ -591,3 +584,5 @@ void AppChooserData::setShellAccess(bool enable)
     m_shellAccess = enable;
     Q_EMIT shellAccessChanged();
 }
+
+#include "moc_appchooserdialog.cpp"
