@@ -26,7 +26,6 @@
 #include <QVBoxLayout>
 #include <QWindow>
 
-#include <KFileFilter>
 #include <KFileFilterCombo>
 #include <KFileWidget>
 #include <KLocalizedString>
@@ -785,3 +784,5 @@ bool FileChooserPortal::isMobile()
     QByteArray mobile = qgetenv("QT_QUICK_CONTROLS_MOBILE");
     return mobile == "true" || mobile == "1";
 }
+
+#include "moc_filechooser.cpp"
